@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0515';
+our $VERSION = '0.0600';
 
 use Moo;
 use strictures 2;
@@ -85,12 +85,41 @@ sub _build_weights {
 }
 
 
+has groups => (
+    is      => 'ro',
+    builder => 1,
+    lazy    => 1,
+);
+
+sub _build_groups {
+    my ($self) = @_;
+    return [ (0) x @{ $self->pool } ];
+}
+
+
+has pool_group => (
+    is       => 'ro',
+    init_arg => undef,
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { return 0 },
 );
 
 
+sub BUILD {
+    my ($self, $args) = @_;
+
+    my %pool_group;
+    for my $i (0 .. @{ $self->pool } - 1) {
+        $pool_group{ $self->pool->[$i] } = $self->groups->[$i];
+    }
+    $self->{pool_group} = \%pool_group;
+}
+
+
 sub motif {
     my ($self) = @_;
 
@@ -99,9 +128,28 @@ sub motif {
     my $format = '%.4f';
 
     my $sum = 0;
+    my $group_num = 0;
+    my $group_name = '';
 
     while ( $sum < $self->size ) {
         my $name = $self->pool_select->();
+
+        # Compute grouping
+        if ($group_num) {
+            $group_num--;
+            $name = $group_name;
+        }
+        else {
+            if ($self->pool_group->{$name}) {
+                $group_num = $self->pool_group->{$name} - 1;
+                $group_name = $name;
+            }
+            else {
+                $group_num = 0;
+                $group_name = '';
+            }
+        }
+
         my $size = $self->_duration($name);
         my $diff = $self->size - $sum;
 
@@ -152,7 +200,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0515
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -186,6 +234,13 @@ version 0.0515
     weights => [0.7, 0.3], # Optional
   );
 
+  # The pool may also be grouped
+  $mdp = Music::Duration::Partition->new(
+    size   => 4,
+    pool   => [qw(hn qn tqn)],
+    groups => [0, 0, 3], # Optional
+  );
+
 =head1 DESCRIPTION
 
 A C<Music::Duration::Partition> divides a musical duration given by
@@ -226,9 +281,9 @@ motif.
 
 Default: C<[ keys %MIDI::Simple::Length ]> (wn, hn, qn, ...)
 
-This can be B<either> a list of duration names, as in the default
-example, or duration values, specified with a preceding 'd'.  A
-mixture of both is not well defined. YMMV
+This can be B<either> a list of duration names, as in the example, or
+duration values, specified with a preceding 'd'.  A mixture of both is
+not well defined. YMMV
 
 =head2 pool_select
 
@@ -251,6 +306,29 @@ weights do not have to sum to 1 and can be any relative numbers.
 
 Default: Equal probability for each pool entry
 
+=head2 groups
+
+  $groups = $mdp->groups;
+
+An array reference of entries that represent the number of times that a
+pool item is selected in sequence.
+
+The number of groups must equal the number of pool entries.
+
+Default: Zero for each pool entry
+
+* Zero and one mean the same thing for grouping.  So if needed, an
+entry should have a value greater than one.
+
+=head2 pool_group
+
+  $pool_group = $mdp->pool_group;
+
+A hash reference of pool keys and group values, respectively.
+
+This attribute is computed and any setting given in the constructor is
+ignored.
+
 =head2 verbose
 
   $verbose = $mdp->verbose;
@@ -267,6 +345,8 @@ Default: C<0>
 
 Create a new C<Music::Duration::Partition> object.
 
+=for Pod::Coverage BUILD
+
 =head2 motif
 
   $motif = $mdp->motif;
